Failure class abstract

Implementers

Constructors

Failure({required String code, required String? message, Object? exception, StackTrace? stacktrace})
const

Properties

code → String
final
exception → Object?
final
hashCode → int
The hash code for this object.
no setteroverride
message → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stacktrace → StackTrace?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override