InternalFailure class

Inheritance

Constructors

InternalFailure(Object exception, StackTrace stacktrace)

Properties

code → String
finalinherited
exception → Object?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stacktrace → StackTrace?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited